@@ -25,31 +25,31 @@ function check_exec()
 
 function check_valid()
 {
-    if [ "${!1}" == "YES" ] || [ "${!1}" == "ON" ]; then
+    if [ "${!1}" == "YES" ] || [ "${!1}" == "ON" ] || [ "${!1}" == "yes" ] || [ "${!1}" == "on" ]; then
         echo "YES"
-        return 1
+        return 0
     fi
-    if [ "${!1}" == "NO" ] || [ "${!1}" == "OFF" ]; then
+    if [ "${!1}" == "NO" ] || [ "${!1}" == "OFF" ] || [ "${!1}" == "no" ] || [ "${!1}" == "off" ]; then
         echo "NO"
-        return 1
+        return 0
     fi
-    echo "${txtred}Invalid value for $1 (${!1}) -- Must be ON, YES, NO, or OFF${txtrst}"
+    printf "${txtred}\nERROR: Invalid value for $1 (${!1}) -- Must be ON, YES, NO, or OFF\n\n${txtrst}" >& 2
     exit 1
 }
 
 #By default, download and then install.
 DOWNLOAD=${DOWNLOAD:-YES}
-DOWNLOAD=$(check_valid DOWNLOAD)
+DOWNLOAD=$(check_valid DOWNLOAD) || exit
 
 BUILD=${BUILD:-YES}
-BUILD=$(check_valid BUILD)
+BUILD=$(check_valid BUILD) || exit
 
 # Force downloading and installation even if the TPL already exists in lib/include
 FORCE=${FORCE:-NO}
-FORCE=$(check_valid FORCE)
+FORCE=$(check_valid FORCE) || exit
 
 DEBUG=${DEBUG:-NO}
-DEBUG=$(check_valid DEBUG)
+DEBUG=$(check_valid DEBUG) || exit
 
 # Shared libraries or static libraries?
 # For CRAY, must explicitly specify SHARED=YES, or it will default to NO
@@ -60,36 +60,36 @@ then
 else
     SHARED="${SHARED:-YES}"
 fi
-SHARED=$(check_valid SHARED)
+SHARED=$(check_valid SHARED) || exit
 
 # Enable Burst-Buffer support in PnetCDF?
 BB=${BB:-NO}
-BB=$(check_valid BB)
+BB=$(check_valid BB) || exit
 
 CRAY=${CRAY:-NO}
-CRAY=$(check_valid CRAY)
+CRAY=$(check_valid CRAY) || exit
 
 MPI=${MPI:-NO}
-MPI=$(check_valid MPI)
+MPI=$(check_valid MPI) || exit
 
 # Which TPLS? (NetCDF always, but can be disabled if using an external version, PnetCDF if MPI=ON)
 NETCDF=${NETCDF:-YES}
-NETCDF=$(check_valid NETCDF)
+NETCDF=$(check_valid NETCDF) || exit
 PNETCDF=${PNETCDF:-${MPI}}
-PNETCDF=$(check_valid PNETCDF)
+PNETCDF=$(check_valid PNETCDF) || exit
 HDF5=${HDF5:-YES}
-HDF5=$(check_valid HDF5)
+HDF5=$(check_valid HDF5) || exit
 CGNS=${CGNS:-${HDF5}}
-CGNS=$(check_valid CGNS)
+CGNS=$(check_valid CGNS) || exit
 
 MATIO=${MATIO:-YES}
-MATIO=$(check_valid MATIO)
+MATIO=$(check_valid MATIO) || exit
 
 PARMETIS=${PARMETIS:-NO}
-PARMETIS=$(check_valid PARMETIS)
+PARMETIS=$(check_valid PARMETIS) || exit
 
 METIS=${METIS:-NO}
-METIS=$(check_valid METIS)
+METIS=$(check_valid METIS) || exit
 
 if [ "$PARMETIS" == "YES" ]
 then
@@ -97,13 +97,13 @@ then
 fi
 
 FMT=${FMT:-YES}
-FMT=$(check_valid FMT)
+FMT=$(check_valid FMT) || exit
 
 GNU_PARALLEL=${GNU_PARALLEL:-YES}
-GNU_PARALLEL=$(check_valid GNU_PARALLEL)
+GNU_PARALLEL=$(check_valid GNU_PARALLEL) || exit
 
 USE_ZLIB_NG=${USE_ZLIB_NG:-NO}
-USE_ZLIB_NG=$(check_valid USE_ZLIB_NG)
+USE_ZLIB_NG=$(check_valid USE_ZLIB_NG) || exit
 
 if [ "${USE_ZLIB_NG}" == "YES" ]
 then
@@ -111,39 +111,39 @@ then
 fi
 
 NEEDS_ZLIB=${NEEDS_ZLIB:-NO}
-NEEDS_ZLIB=$(check_valid NEEDS_ZLIB)
+NEEDS_ZLIB=$(check_valid NEEDS_ZLIB) || exit
 
 NEEDS_SZIP=${NEEDS_SZIP:-NO}
-NEEDS_SZIP=$(check_valid NEEDS_SZIP)
+NEEDS_SZIP=$(check_valid NEEDS_SZIP) || exit
 
 USE_AEC=${USE_AEC:-NO}
-USE_AEC=$(check_valid USE_AEC)
+USE_AEC=$(check_valid USE_AEC) || exit
 
 KOKKOS=${KOKKOS:-NO}
-KOKKOS=$(check_valid KOKKOS)
+KOKKOS=$(check_valid KOKKOS) || exit
 
 H5VERSION=${H5VERSION:-V114}
 # Build/Install the HDF5 C++ library?
 H5CPP=${H5CPP:-NO}
-H5CPP=$(check_valid H5CPP)
+H5CPP=$(check_valid H5CPP) || exit
 
 FAODEL=${FAODEL:-NO}
-FAODEL=$(check_valid FAODEL)
+FAODEL=$(check_valid FAODEL) || exit
 
 BOOST=${BOOST:-NO}
-BOOST=$(check_valid BOOST)
+BOOST=$(check_valid BOOST) || exit
 
 ADIOS2=${ADIOS2:-NO}
-ADIOS2=$(check_valid ADIOS2)
+ADIOS2=$(check_valid ADIOS2) || exit
 
 CATALYST2=${CATALYST2:-NO}
-CATALYST2=$(check_valid CATALYST2)
+CATALYST2=$(check_valid CATALYST2) || exit
 
 GTEST=${GTEST:-${FAODEL}}
-GTEST=$(check_valid GTEST)
+GTEST=$(check_valid GTEST) || exit
 
 CATCH2=${CATCH2:-YES}
-CATCH2=$(check_valid CATCH2)
+CATCH2=$(check_valid CATCH2) || exit
 
 
 SUDO=${SUDO:-}
@@ -151,7 +151,7 @@ JOBS=${JOBS:-2}
 VERBOSE=${VERBOSE:-1}
 
 USE_PROXY=${USE_PROXY:-NO}
-USE_PROXY=$(check_valid USE_PROXY)
+USE_PROXY=$(check_valid USE_PROXY) || exit
 
 if [ "${USE_PROXY}" == "YES" ]
 then
@@ -159,7 +159,7 @@ then
     export https_proxy="https://proxy.sandia.gov:80"
 fi
 
-pwd
+echo "Current Location = $(pwd)"
 INSTALL_PATH=${INSTALL_PATH:-${ACCESS}}
 
 if [ "$MPI" == "YES" ] && [ "$CRAY" == "YES" ]
@@ -418,26 +418,16 @@ then
     then
 	echo "${txtgrn}+++ HDF5${txtrst}"
 	hdf_suffix=""
-	if [ "${H5VERSION}" == "V18" ]; then
-            hdf_version="1.8.23"
-            hdf_base="1.8"
-	elif [ "${H5VERSION}" == "V110" ]; then
-            hdf_version="1.10.10"
-            hdf_base="1.10"
+	if [ "${H5VERSION}" == "V110" ]; then
+	    hdf_version="hdf5-1_10_11"
 	elif [ "${H5VERSION}" == "V112" ]; then
-            hdf_version="1.12.2"
-            hdf_base="1.12"
-	elif [ "${H5VERSION}" == "V113" ]; then
-            hdf_version="1.13.1"
-            hdf_base="1.13"
+            hdf_version="hdf5-1_12_3"
 	elif [ "${H5VERSION}" == "V114" ]; then
-            hdf_version="1.14.3"
-            hdf_base="1.14"
-	    hdf_suffix=""
+            hdf_version="hdf5_1.14.4.3"
 	elif [ "${H5VERSION}" == "develop" ]; then
             hdf_version="develop"
 	else
-            echo 1>&2 ${txtred}Invalid HDF5 version specified: ${H5VERSION}.  Must be one of V18, V110, V112. exiting.${txtrst}
+            echo 1>&2 ${txtred}Invalid HDF5 version specified: ${H5VERSION}.  Must be one of V110, V112, or V114. exiting.${txtrst}
             exit 1
 	fi
 	
@@ -449,21 +439,21 @@ then
             rm -rf hdf5-${hdf_version}${hdf_suffix}
             rm -f hdf5-${hdf_version}${hdf_suffix}.tar.bz2
             if [ "${H5VERSION}" == "develop" ]; then
-		git clone https://github.com/HDFGroup/hdf5.git hdf5-develop
+		git clone --depth=1 https://github.com/HDFGroup/hdf5.git hdf5-develop
             else
-		wget --no-check-certificate https://support.hdfgroup.org/ftp/HDF5/releases/hdf5-${hdf_base}/hdf5-${hdf_version}/src/hdf5-${hdf_version}${hdf_suffix}.tar.bz2
+		wget --no-check-certificate https://github.com/HDFGroup/hdf5/archive/refs/tags/${hdf_version}.tar.gz
             fi
             if [ "${H5VERSION}" != "develop" ]
             then
-		tar -jxf hdf5-${hdf_version}${hdf_suffix}.tar.bz2
-		rm -f hdf5-${hdf_version}${hdf_suffix}.tar.bz2
+		tar -zxf ${hdf_version}.tar.gz
+		rm -f ${hdf_version}.tar.gz
             fi
 	fi
 	
 	if [ "$BUILD" == "YES" ]
 	then
             echo "${txtgrn}+++ Configuring, Building, and Installing...${txtrst}"
-            cd hdf5-${hdf_version}${hdf_suffix} || exit
+            cd hdf5-${hdf_version} || exit
             rm -rf build
             mkdir build
             cd build || exit
@@ -482,6 +472,7 @@ then
             fi
 	fi
 	# Create default plugin directory...
+	mkdir  ${INSTALL_PATH}/lib
 	mkdir  ${INSTALL_PATH}/lib/hdf5
 	mkdir  ${INSTALL_PATH}/lib/hdf5/lib
 	mkdir  ${INSTALL_PATH}/lib/hdf5/lib/plugin
@@ -497,7 +488,7 @@ then
     if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libpnetcdf.a ]
     then
         echo "${txtgrn}+++ PnetCDF${txtrst}"
-        pnet_version="1.12.3"
+        pnet_version="1.13.0"
         pnet_base="pnetcdf"
         cd $ACCESS || exit
         cd TPL/pnetcdf || exit
@@ -613,6 +604,7 @@ then
             echo "${txtgrn}+++ Configuring, Building, and Installing...${txtrst}"
             cd CGNS || exit
             git checkout v4.4.0
+	    git am ../CGNS-Allow-more-liberal-version-matching.patch
             rm -rf build
             mkdir build
             cd build || exit
@@ -693,7 +685,7 @@ then
         then
             echo "${txtgrn}+++ Downloading...${txtrst}"
             rm -rf parmetis
-            git clone https://github.com/gsjaardema/parmetis
+            git clone --depth=1 https://github.com/gsjaardema/parmetis
         fi
 
         if [ "$BUILD" == "YES" ]
@@ -774,7 +766,7 @@ then
         echo "${txtgrn}+++ FMT${txtrst}"
         cd $ACCESS || exit
         cd TPL/fmt || exit
-        fmt_version="10.2.0"
+        fmt_version="10.2.1"
 
         if [ "$DOWNLOAD" == "YES" ]
         then
@@ -867,7 +859,7 @@ then
         then
             echo "${txtgrn}+++ Downloading...${txtrst}"
             rm -rf ADIOS2
-            git clone https://github.com/ornladios/ADIOS2.git
+            git clone --depth=1 https://github.com/ornladios/ADIOS2.git
         fi
 
         if [ "$BUILD" == "YES" ]
@@ -984,7 +976,7 @@ fi
 # =================== INSTALL catch2  ===============
 if [ "$CATCH2" == "YES" ]
 then
-    if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libcatch.a ]
+    if [ "$FORCE" == "YES" ] || ! [ -e $INSTALL_PATH/lib/libCatch2.a ]
     then
         echo "${txtgrn}+++ Catch2${txtrst}"
         cd $ACCESS || exit
@@ -1102,7 +1094,7 @@ then
     then
       echo "${txtgrn}+++ Downloading...${txtrst}"
       rm -rf faodel*
-      git clone https://github.com/sandialabs/faodel.git
+      git clone --depth=1 https://github.com/sandialabs/faodel.git
     fi
 
     if [ "$BUILD" == "YES" ]
